@@ -1,31 +1,9 @@
-#######################################################
-#
-# Family Tree generation program, v2.0
-# Written by Ferenc Bodon and Simon Ward, March 2000 (simonward.com)
-# Copyright (C) 2000 Ferenc Bodon, Simon K Ward
-#
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License
-# as published by the Free Software Foundation; either version 2
-# of the License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# For a copy of the GNU General Public License, visit
-# http://www.gnu.org or write to the Free Software Foundation, Inc.,
-# 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-#
-#######################################################
-
 package Ftree::PersonPage;
 use strict;
 use warnings;
 
 use version;
-our $VERSION = qv('2.3.39');
+our $VERSION = qv('2.3.40');
 
 use Ftree::FamilyTreeBase;
 use Sub::Exporter -setup => { exports => [ qw(new main) ] };
@@ -254,8 +232,8 @@ sub _print_people_list {
 
         foreach my $person ( @{$people_array_r} ) {
             if (   $person != $self->{target_person}
-                && $person != $Person::unknown_male
-                && $person != $Person::unknown_female )
+                && $person != $Ftree::Person::unknown_male
+                && $person != $Ftree::Person::unknown_female )
             {
                 print $self->aref_tree( $person->get_name()->get_full_name(),
                     $person, 0 ),
